@@ -53,7 +53,7 @@ class Client():
                 json_response = json.dumps(dict_response)
 
                 print(json_response)
-                
+
                 return json_response
             except:
                 resposne = {
@@ -115,9 +115,3 @@ class Client():
             print(json_response)
 
             return json_response
-
-
-
-s = Client('mgunityrone@gmai.com', '123abc!!!')
-
-s.send_single_sms('Hello world', '263777606983', 'Sup')
\ No newline at end of file
